@@ -42,7 +42,7 @@ sub _format_table {
     my ($Quiki, $chunk) = @_;
 
     my @c = split /\n/, $chunk;
-    my $table = "<table class=\"quiki_table\">\n";
+    my $table = "<table>\n";
 
     while (@c && $c[0] =~ /^(\^|\|)/) {
         $c[0] =~ s/^(.)//;
